@@ -30,6 +30,12 @@ RSS::AVAILABLE_PARSERS.each do |parser|
   RSS::Parser.default_parser = parser
   break unless defined?(Test::Unit::AutoRunner)
   GC.start
-  Test::Unit::AutoRunner.run($0, File.dirname($0), argv.dup)
+  args = [File.dirname($0), argv.dup]
+  if Test::Unit::AutoRunner.respond_to?(:standalone?)
+    args.unshift(false)
+  else
+    args.unshift($0)
+  end
+  Test::Unit::AutoRunner.run(*args)
   puts
 end
